body /* This body tag requires the use of one of the sets of banner and/or text div ids */
	{
	margin: 0px 0px 0px 0px;
	padding: 0px 0px 0px 0px;
	background: #ffffff; 
	color: #000000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 70%;
	width: 100%;
	}
	
table
	{
	margin: 0px 0px 0px 0px;
	padding: 0px 0px 0px 0px;
	background: #ffffff; 
	color: #000000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 100%;
	}
	
h1, h2, h3, h4
	{
	font-family: Verdana, Arial, Helvetica, sans-serif;
	margin-bottom: .4em; 
	margin-top: 1em;
	font-weight: bold;
	}
h1
	{
	font-size: 150%;
	margin-top: 0em;
	}
h2
	{
	font-size: 130%;
	}
h3
	{
	font-size: 115%;
	}
h4
	{
	font-size: 100%;
	}
